@@ -70,16 +70,51 @@ from uipath.eval.evaluators.tool_call_output_evaluator import (
 class EvaluatorFactory:
     """Factory class for creating evaluator instances based on configuration."""
 
+    @staticmethod
+    def _prepare_evaluator_config(data: Dict[str, Any]) -> Dict[str, Any]:
+        """Prepare evaluator config by merging top-level fields into evaluatorConfig.
+
+        This allows flexibility in specifying fields like 'name' and 'description' either at the
+        top level or within evaluatorConfig. Top-level values take precedence if both exist.
+
+        Args:
+            data: The raw evaluator data dictionary
+
+        Returns:
+            The prepared evaluatorConfig with merged fields
+        """
+        evaluator_config = data.get("evaluatorConfig", {})
+        if not isinstance(evaluator_config, dict):
+            evaluator_config = {}
+        else:
+            # Create a copy to avoid modifying the original
+            evaluator_config = evaluator_config.copy()
+
+        # Merge top-level 'name' into config if present
+        if "name" in data and data["name"] is not None:
+            # Top-level name takes precedence
+            evaluator_config["name"] = data["name"]
+
+        # Merge top-level 'description' into config if present
+        if "description" in data and data["description"] is not None:
+            # Top-level description takes precedence
+            evaluator_config["description"] = data["description"]
+
+        return evaluator_config
+
     @classmethod
-    def create_evaluator(cls, data: Dict[str, Any]) -> BaseEvaluator[Any, Any, Any]:
+    def create_evaluator(
+        cls, data: Dict[str, Any], evaluators_dir: Path | None = None
+    ) -> BaseEvaluator[Any, Any, Any]:
         if data.get("version", None) == "1.0":
-            return cls._create_evaluator_internal(data)
+            return cls._create_evaluator_internal(data, evaluators_dir)
         else:
             return cls._create_legacy_evaluator_internal(data)
 
     @staticmethod
     def _create_evaluator_internal(
         data: Dict[str, Any],
+        evaluators_dir: Path | None = None,
     ) -> BaseEvaluator[Any, Any, Any]:
         # check custom evaluator
         evaluator_schema = data.get("evaluatorSchema", "")
@@ -88,7 +123,7 @@ class EvaluatorFactory:
         )
         if success:
             return EvaluatorFactory._create_coded_evaluator_internal(
-                data, file_path, class_name
+                data, file_path, class_name, evaluators_dir
             )
 
         # use built-in evaluators
@@ -134,18 +169,22 @@ class EvaluatorFactory:
             raise ValueError("Evaluator 'id' must be a non-empty string")
         return ContainsEvaluator(
             id=evaluator_id,
-            config=data.get("evaluatorConfig"),
+            config=EvaluatorFactory._prepare_evaluator_config(data),
         )  # type: ignore
 
     @staticmethod
     def _create_coded_evaluator_internal(
-        data: Dict[str, Any], file_path_str: str, class_name: str
+        data: Dict[str, Any],
+        file_path_str: str,
+        class_name: str,
+        evaluators_dir: Path | None = None,
     ) -> BaseEvaluator[Any, Any, Any]:
         """Create a coded evaluator by dynamically loading from a Python file.
 
         Args:
             data: Dictionary containing evaluator configuration with evaluatorTypeId
                   in format "file://path/to/file.py:ClassName"
+            evaluators_dir: Directory containing evaluator configuration files
 
         Returns:
             Instance of the dynamically loaded evaluator class
@@ -156,18 +195,23 @@ class EvaluatorFactory:
         file_path = Path(file_path_str)
         if not file_path.is_absolute():
             if not file_path.exists():
-                file_path = (
-                    Path.cwd()
-                    / EVALS_DIRECTORY_NAME
-                    / "evaluators"
-                    / "custom"
-                    / file_path_str
-                )
+                # Try using the provided evaluators_dir first
+                if evaluators_dir is not None:
+                    file_path = evaluators_dir / "custom" / file_path_str
+                else:
+                    # Fall back to the old behavior
+                    file_path = (
+                        Path.cwd()
+                        / EVALS_DIRECTORY_NAME
+                        / "evaluators"
+                        / "custom"
+                        / file_path_str
+                    )
 
         if not file_path.exists():
             raise ValueError(
                 f"Evaluator file not found: {file_path}. "
-                f"Make sure the file exists in evals/evaluators/custom/"
+                f"Make sure the file exists in the evaluators/custom/ directory"
             )
 
         module_name = f"_custom_evaluator_{file_path.stem}_{id(data)}"
@@ -205,7 +249,7 @@ class EvaluatorFactory:
             raise ValueError("Evaluator 'id' must be a non-empty string")
         return evaluator_class(
             id=evaluator_id,
-            config=data.get("evaluatorConfig", {}),
+            config=EvaluatorFactory._prepare_evaluator_config(data),
         )  # type: ignore
 
     @staticmethod
@@ -215,7 +259,7 @@ class EvaluatorFactory:
         return TypeAdapter(ExactMatchEvaluator).validate_python(
             {
                 "id": data.get("id"),
-                "config": data.get("evaluatorConfig"),
+                "config": EvaluatorFactory._prepare_evaluator_config(data),
             }
         )
 
@@ -226,7 +270,7 @@ class EvaluatorFactory:
         return TypeAdapter(JsonSimilarityEvaluator).validate_python(
             {
                 "id": data.get("id"),
-                "config": data.get("evaluatorConfig"),
+                "config": EvaluatorFactory._prepare_evaluator_config(data),
             }
         )
 
@@ -237,7 +281,7 @@ class EvaluatorFactory:
         return TypeAdapter(LLMJudgeOutputEvaluator).validate_python(
             {
                 "id": data.get("id"),
-                "config": data.get("evaluatorConfig"),
+                "config": EvaluatorFactory._prepare_evaluator_config(data),
             }
         )
 
@@ -248,7 +292,7 @@ class EvaluatorFactory:
         return TypeAdapter(LLMJudgeStrictJSONSimilarityOutputEvaluator).validate_python(
             {
                 "id": data.get("id"),
-                "config": data.get("evaluatorConfig"),
+                "config": EvaluatorFactory._prepare_evaluator_config(data),
             }
         )
 
@@ -259,7 +303,7 @@ class EvaluatorFactory:
         return TypeAdapter(LLMJudgeTrajectoryEvaluator).validate_python(
             {
                 "id": data.get("id"),
-                "config": data.get("evaluatorConfig"),
+                "config": EvaluatorFactory._prepare_evaluator_config(data),
             }
         )
 
@@ -270,7 +314,7 @@ class EvaluatorFactory:
         return TypeAdapter(ToolCallArgsEvaluator).validate_python(
             {
                 "id": data.get("id"),
-                "config": data.get("evaluatorConfig"),
+                "config": EvaluatorFactory._prepare_evaluator_config(data),
             }
         )
 
@@ -281,7 +325,7 @@ class EvaluatorFactory:
         return TypeAdapter(ToolCallCountEvaluator).validate_python(
             {
                 "id": data.get("id"),
-                "config": data.get("evaluatorConfig"),
+                "config": EvaluatorFactory._prepare_evaluator_config(data),
             }
         )
 
@@ -292,7 +336,7 @@ class EvaluatorFactory:
         return TypeAdapter(ToolCallOrderEvaluator).validate_python(
             {
                 "id": data.get("id"),
-                "config": data.get("evaluatorConfig"),
+                "config": EvaluatorFactory._prepare_evaluator_config(data),
             }
         )
 
@@ -303,7 +347,7 @@ class EvaluatorFactory:
         return TypeAdapter(ToolCallOutputEvaluator).validate_python(
             {
                 "id": data.get("id"),
-                "config": data.get("evaluatorConfig"),
+                "config": EvaluatorFactory._prepare_evaluator_config(data),
             }
         )
 
@@ -314,7 +358,7 @@ class EvaluatorFactory:
         return TypeAdapter(LLMJudgeTrajectorySimulationEvaluator).validate_python(
             {
                 "id": data.get("id"),
-                "config": data.get("evaluatorConfig"),
+                "config": EvaluatorFactory._prepare_evaluator_config(data),
             }
         )
 
