@@ -371,7 +371,7 @@ class UiPathEvalRuntime(UiPathBaseRuntime, Generic[T, C]):
         await event_bus.publish(
             EvaluationEvents.CREATE_EVAL_RUN,
             EvalRunCreatedEvent(
-                execution_id=self.execution_id,
+                execution_id=execution_id,
                 eval_item=eval_item,
             ),
         )
@@ -466,7 +466,7 @@ class UiPathEvalRuntime(UiPathBaseRuntime, Generic[T, C]):
             await event_bus.publish(
                 EvaluationEvents.UPDATE_EVAL_RUN,
                 EvalRunUpdatedEvent(
-                    execution_id=self.execution_id,
+                    execution_id=execution_id,
                     eval_item=eval_item,
                     eval_results=evaluation_item_results,
                     success=not agent_execution_output.result.error,
@@ -491,7 +491,7 @@ class UiPathEvalRuntime(UiPathBaseRuntime, Generic[T, C]):
                 )
 
             eval_run_updated_event = EvalRunUpdatedEvent(
-                execution_id=self.execution_id,
+                execution_id=execution_id,
                 eval_item=eval_item,
                 eval_results=[],
                 success=False,
@@ -649,7 +649,7 @@ class UiPathEvalRuntime(UiPathBaseRuntime, Generic[T, C]):
             try:
                 evaluator_id = data.get("id")
                 if evaluator_id in evaluator_ref_ids:
-                    evaluator = EvaluatorFactory.create_evaluator(data)
+                    evaluator = EvaluatorFactory.create_evaluator(data, evaluators_dir)
                     evaluators.append(evaluator)
                     found_evaluator_ids.add(evaluator_id)
             except Exception as e:
