@@ -10,6 +10,7 @@ from typing import Any, AsyncIterator, Dict, Literal, Optional, Protocol, Tuple
 
 from pydantic import BaseModel, Field, TypeAdapter
 
+from ..._config import UiPathConfig
 from .._utils._console import ConsoleLogger
 from ..models.runtime_schema import RuntimeSchema
 from ._constants import is_binary_file
@@ -205,7 +206,9 @@ def get_project_config(directory: str) -> dict[str, str]:
     return {
         "project_name": toml_data["name"],
         "description": toml_data["description"],
-        "entryPoints": [ep.model_dump(by_alias=True) for ep in config_data.entrypoints],
+        "entryPoints": [ep.model_dump(by_alias=True) for ep in config_data.entrypoints]
+        if config_data.entrypoints
+        else [],
         "version": toml_data["version"],
         "authors": toml_data["authors"],
         "dependencies": toml_data.get("dependencies", {}),
@@ -214,6 +217,24 @@ def get_project_config(directory: str) -> dict[str, str]:
     }
 
 
+def validate_project_files(directory: str) -> None:
+    required_files = [
+        UiPathConfig.bindings_file_path,
+        UiPathConfig.entry_points_file_path,
+    ]
+
+    missing_files = []
+    for file_path in required_files:
+        if not os.path.isfile(os.path.join(directory, str(file_path))):
+            missing_files.append(f"'{file_path}'")
+
+    if missing_files:
+        missing_str = ", ".join(missing_files)
+        console.error(
+            f"Missing required files: {missing_str}. Please run 'uipath init'."
+        )
+
+
 def validate_config(config: dict[str, str]) -> None:
     """Validate the combined project configuration.
 
