@@ -5,6 +5,7 @@ from .attachments_service import AttachmentsService
 from .buckets_service import BucketsService
 from .connections_service import ConnectionsService
 from .context_grounding_service import ContextGroundingService
+from .conversations_service import ConversationsService
 from .documents_service import DocumentsService
 from .entities_service import EntitiesService
 from .external_application_service import ExternalApplicationService
@@ -31,4 +32,5 @@ __all__ = [
     "FolderService",
     "EntitiesService",
     "ExternalApplicationService",
+    "ConversationsService",
 ]
