@@ -13,6 +13,7 @@ from ._services import (
     BucketsService,
     ConnectionsService,
     ContextGroundingService,
+    ConversationsService,
     DocumentsService,
     EntitiesService,
     FolderService,
@@ -22,6 +23,7 @@ from ._services import (
     UiPathLlmChatService,
     UiPathOpenAIService,
 )
+from ._services.resource_catalog_service import ResourceCatalogService
 from ._utils._auth import resolve_config
 from ._utils._logs import setup_logging
 from .models.errors import BaseUrlMissingError, SecretMissingError
@@ -119,3 +121,13 @@ class UiPath:
     @property
     def entities(self) -> EntitiesService:
         return EntitiesService(self._config, self._execution_context)
+
+    @cached_property
+    def resource_catalog(self) -> ResourceCatalogService:
+        return ResourceCatalogService(
+            self._config, self._execution_context, self.folders
+        )
+
+    @property
+    def conversational(self) -> ConversationsService:
+        return ConversationsService(self._config, self._execution_context)
