@@ -1,3 +1,4 @@
+import json
 from unittest.mock import AsyncMock, MagicMock
 from urllib.parse import unquote_plus
 
@@ -16,6 +17,10 @@ from uipath.models import (
     ConnectionToken,
     EventArguments,
 )
+from uipath.models.connections import (
+    ActivityMetadata,
+    ActivityParameterLocationInfo,
+)
 from uipath.utils.dynamic_schema import jsonschema_to_pydantic
 
 
@@ -1233,3 +1238,419 @@ class TestConnectionsService:
         # Verify exactly 2 requests were made (initial + 1 JIT level, then stopped)
         requests = httpx_mock.get_requests()
         assert len(requests) == 2
+
+
+@pytest.fixture
+def simple_activity_metadata() -> ActivityMetadata:
+    """Simple activity metadata for non-path tests."""
+    return ActivityMetadata(
+        object_path="/elements/test-connector/test-activity",
+        method_name="POST",
+        content_type="application/json",
+        parameter_location_info=ActivityParameterLocationInfo(
+            query_params=["query_param", "query_param2"],
+            header_params=["custom_header", "custom_header2"],
+            path_params=[],
+            multipart_params=[],
+            body_fields=["body_field1", "body_field2", "body_field3"],
+        ),
+    )
+
+
+@pytest.fixture
+def path_activity_metadata() -> ActivityMetadata:
+    """Sample activity metadata for testing with all parameter types."""
+    return ActivityMetadata(
+        object_path="/elements/test-connector/users/{userId}/posts/{postId}",
+        method_name="POST",
+        content_type="application/json",
+        parameter_location_info=ActivityParameterLocationInfo(
+            query_params=[],
+            header_params=[],
+            path_params=["userId", "postId"],
+            multipart_params=[],
+            body_fields=[],
+        ),
+    )
+
+
+@pytest.fixture
+def multipart_activity_metadata() -> ActivityMetadata:
+    """Sample multipart activity metadata for testing."""
+    return ActivityMetadata(
+        object_path="/elements/test-connector/upload",
+        method_name="POST",
+        content_type="multipart/form-data",
+        parameter_location_info=ActivityParameterLocationInfo(
+            query_params=[],
+            header_params=[],
+            path_params=[],
+            multipart_params=["file_param"],
+            body_fields=["description"],
+        ),
+    )
+
+
+class TestConnectorActivityInvocation:
+    def test_invoke_activity_with_query_params(
+        self,
+        httpx_mock: HTTPXMock,
+        service: ConnectionsService,
+        simple_activity_metadata: ActivityMetadata,
+    ) -> None:
+        """Test invoking with query parameters only."""
+        connection_id = "test-connection-123"
+        activity_input = {
+            "query_param": "test search query",
+            "query_param2": "additional query",
+        }
+        expected_response = {"results": [], "total": 0}
+
+        httpx_mock.add_response(
+            method="POST",
+            status_code=200,
+            json=expected_response,
+        )
+
+        _ = service.invoke_activity(
+            activity_metadata=simple_activity_metadata,
+            connection_id=connection_id,
+            activity_input=activity_input,
+        )
+
+        sent_request = httpx_mock.get_request()
+        if sent_request is None:
+            raise Exception("No request was sent")
+
+        # Check query parameters
+        assert sent_request.url.params["query_param"] == "test search query"
+        assert sent_request.url.params["query_param2"] == "additional query"
+
+    def test_invoke_activity_with_header_params(
+        self,
+        httpx_mock: HTTPXMock,
+        service: ConnectionsService,
+        simple_activity_metadata: ActivityMetadata,
+    ) -> None:
+        """Test invoking with header parameters only."""
+        connection_id = "test-connection-123"
+        activity_input = {
+            "custom_header": "secret-api-key",
+            "custom_header2": "client-123",
+        }
+        expected_response = {"authenticated": True}
+
+        httpx_mock.add_response(
+            method="POST",
+            status_code=200,
+            json=expected_response,
+        )
+
+        _ = service.invoke_activity(
+            activity_metadata=simple_activity_metadata,
+            connection_id=connection_id,
+            activity_input=activity_input,
+        )
+
+        sent_request = httpx_mock.get_request()
+        if sent_request is None:
+            raise Exception("No request was sent")
+
+        # Check custom headers
+        assert sent_request.headers["custom_header"] == "secret-api-key"
+        assert sent_request.headers["custom_header2"] == "client-123"
+
+    def test_invoke_activity_sets_standard_headers(
+        self,
+        httpx_mock: HTTPXMock,
+        service: ConnectionsService,
+        simple_activity_metadata: ActivityMetadata,
+    ) -> None:
+        """Test invoking sets standard headers correctly."""
+        connection_id = "test-connection-123"
+        activity_input = {
+            "body_field1": "Test Item",
+        }
+        expected_response = {"status": "success"}
+
+        httpx_mock.add_response(
+            method="POST",
+            status_code=200,
+            json=expected_response,
+        )
+
+        _ = service.invoke_activity(
+            activity_metadata=simple_activity_metadata,
+            connection_id=connection_id,
+            activity_input=activity_input,
+        )
+
+        sent_request = httpx_mock.get_request()
+        if sent_request is None:
+            raise Exception("No request was sent")
+
+        # Check standard headers
+        assert sent_request.headers["x-uipath-originator"] == "uipath-python"
+        assert sent_request.headers["x-uipath-source"] == "uipath-python"
+
+    def test_invoke_activity_with_body_fields(
+        self,
+        httpx_mock: HTTPXMock,
+        service: ConnectionsService,
+        simple_activity_metadata: ActivityMetadata,
+    ) -> None:
+        """Test invoking with JSON body fields only."""
+        connection_id = "test-connection-123"
+        activity_input = {
+            "body_field1": "Test Item",
+            "body_field2": "This is a test item",
+            "body_field3": "high",
+        }
+        expected_response = {"id": 456, "status": "created"}
+
+        httpx_mock.add_response(
+            method="POST",
+            status_code=200,
+            json=expected_response,
+        )
+
+        _ = service.invoke_activity(
+            activity_metadata=simple_activity_metadata,
+            connection_id=connection_id,
+            activity_input=activity_input,
+        )
+
+        sent_request = httpx_mock.get_request()
+        if sent_request is None:
+            raise Exception("No request was sent")
+
+        # Check JSON body
+        request_json = json.loads(sent_request.content.decode())
+        assert request_json == {
+            "body_field1": "Test Item",
+            "body_field2": "This is a test item",
+            "body_field3": "high",
+        }
+
+    def test_invoke_activity_with_path_parameters(
+        self,
+        httpx_mock: HTTPXMock,
+        service: ConnectionsService,
+        path_activity_metadata: ActivityMetadata,
+    ) -> None:
+        """Test invoking with path parameters only."""
+        connection_id = "test-connection-123"
+        activity_input = {
+            "userId": "user456",
+            "postId": "post789",
+        }
+        expected_response = {"user": "user456", "post": "post789"}
+
+        httpx_mock.add_response(
+            method="POST",
+            status_code=200,
+            json=expected_response,
+        )
+
+        _ = service.invoke_activity(
+            activity_metadata=path_activity_metadata,
+            connection_id=connection_id,
+            activity_input=activity_input,
+        )
+
+        sent_request = httpx_mock.get_request()
+        if sent_request is None:
+            raise Exception("No request was sent")
+
+        # Verify URL path substitution worked correctly
+        assert sent_request.url.path.endswith(
+            "/elements_/v3/element/instances/test-connection-123/elements/test-connector/users/user456/posts/post789"
+        )
+
+    def test_invoke_activity_multipart_request(
+        self,
+        httpx_mock: HTTPXMock,
+        service: ConnectionsService,
+        multipart_activity_metadata: ActivityMetadata,
+    ) -> None:
+        """Test invoking an Integration Service activity with multipart content."""
+        connection_id = "test-connection-123"
+        activity_input = {
+            "file_param": b"test file content",
+            "description": "Test file upload",
+        }
+        expected_response = {"upload_id": "upload123", "status": "success"}
+
+        httpx_mock.add_response(
+            method="POST",
+            status_code=200,
+            json=expected_response,
+        )
+
+        _ = service.invoke_activity(
+            activity_metadata=multipart_activity_metadata,
+            connection_id=connection_id,
+            activity_input=activity_input,
+        )
+
+        sent_request = httpx_mock.get_request()
+        if sent_request is None:
+            raise Exception("No request was sent")
+
+        assert "multipart/form-data" in sent_request.headers.get("content-type", "")
+
+    @pytest.mark.asyncio
+    async def test_invoke_activity_async_json_request(
+        self,
+        httpx_mock: HTTPXMock,
+        service: ConnectionsService,
+        simple_activity_metadata: ActivityMetadata,
+    ) -> None:
+        """Test async invocation of an Integration Service activity."""
+        connection_id = "test-connection-123"
+        activity_input = {
+            "query_param": "test_query",
+            "body_field1": "async_value1",
+            "body_field2": "async_value2",
+        }
+        expected_response = {"result": "async_success", "data": {"id": 456}}
+
+        httpx_mock.add_response(
+            method="POST",
+            status_code=200,
+            json=expected_response,
+        )
+
+        response = await service.invoke_activity_async(
+            activity_metadata=simple_activity_metadata,
+            connection_id=connection_id,
+            activity_input=activity_input,
+        )
+
+        assert response == expected_response
+
+    def test_invoke_activity_with_none_values_filtered(
+        self,
+        httpx_mock: HTTPXMock,
+        service: ConnectionsService,
+        simple_activity_metadata: ActivityMetadata,
+    ) -> None:
+        """Test that None values are filtered out from the request."""
+        connection_id = "test-connection-123"
+        activity_input = {
+            "query_param": "test_query",
+            "custom_header": None,  # This should be filtered out
+            "body_field1": "value1",
+            "body_field2": None,  # This should be filtered out
+        }
+        expected_response = {"result": "success"}
+
+        httpx_mock.add_response(
+            method="POST",
+            status_code=200,
+            json=expected_response,
+        )
+
+        _ = service.invoke_activity(
+            activity_metadata=simple_activity_metadata,
+            connection_id=connection_id,
+            activity_input=activity_input,
+        )
+
+        sent_request = httpx_mock.get_request()
+        if sent_request is None:
+            raise Exception("No request was sent")
+
+        # custom_header should not be present since it was None
+        assert "custom_header" not in sent_request.headers
+
+        # Only non-None body fields should be present
+        request_json = json.loads(sent_request.content.decode())
+        assert request_json == {"body_field1": "value1"}
+
+    def test_invoke_activity_unknown_parameter_raises_error(
+        self,
+        service: ConnectionsService,
+        simple_activity_metadata: ActivityMetadata,
+    ) -> None:
+        """Test that unknown parameters raise a ValueError."""
+        connection_id = "test-connection-123"
+        activity_input = {
+            "unknown_param": "value",  # This parameter doesn't exist in metadata
+        }
+
+        with pytest.raises(
+            ValueError,
+            match="Parameter unknown_param does not exist in activity metadata",
+        ):
+            service.invoke_activity(
+                activity_metadata=simple_activity_metadata,
+                connection_id=connection_id,
+                activity_input=activity_input,
+            )
+
+    def test_invoke_activity_unsupported_content_type_raises_error(
+        self,
+        service: ConnectionsService,
+    ) -> None:
+        """Test that unsupported content types raise a ValueError."""
+        unsupported_metadata = ActivityMetadata(
+            object_path="/elements/test-connector/test-activity",
+            method_name="POST",
+            content_type="application/xml",  # Unsupported content type
+            parameter_location_info=ActivityParameterLocationInfo(
+                query_params=[],
+                header_params=[],
+                path_params=[],
+                multipart_params=[],
+                body_fields=["xml_data"],
+            ),
+        )
+
+        connection_id = "test-connection-123"
+        activity_input = {"xml_data": "<test>data</test>"}
+
+        with pytest.raises(
+            ValueError, match="Unsupported content type: application/xml"
+        ):
+            service.invoke_activity(
+                activity_metadata=unsupported_metadata,
+                connection_id=connection_id,
+                activity_input=activity_input,
+            )
+
+    def test_invoke_activity_empty_input(
+        self,
+        httpx_mock: HTTPXMock,
+        service: ConnectionsService,
+    ) -> None:
+        """Test invoking with empty input."""
+        activity_metadata = ActivityMetadata(
+            object_path="/elements/test-connector/ping",
+            method_name="GET",
+            content_type="application/json",
+            parameter_location_info=ActivityParameterLocationInfo(
+                query_params=[],
+                header_params=[],
+                path_params=[],
+                multipart_params=[],
+                body_fields=[],
+            ),
+        )
+
+        connection_id = "test-connection-123"
+        expected_response = {"status": "pong"}
+
+        httpx_mock.add_response(
+            method="GET",
+            status_code=200,
+            json=expected_response,
+        )
+
+        result = service.invoke_activity(
+            activity_metadata=activity_metadata,
+            connection_id=connection_id,
+            activity_input={},
+        )
+
+        assert result == expected_response
